@@ -326,12 +326,17 @@ ece_event_update_timezone (ECompEditorEvent *event_editor,
 
 	if (zone) {
 		GtkWidget *edit_widget;
+		icaltimezone *cfg_zone;
 
 		edit_widget = e_comp_editor_property_part_get_edit_widget (event_editor->priv->timezone);
 
 		e_timezone_entry_set_timezone (E_TIMEZONE_ENTRY (edit_widget), zone);
 
-		if (zone != calendar_config_get_icaltimezone ()) {
+		cfg_zone = calendar_config_get_icaltimezone ();
+
+		if (zone && cfg_zone && zone != cfg_zone &&
+		    (g_strcmp0 (icaltimezone_get_location (zone), icaltimezone_get_location (cfg_zone)) != 0 ||
+		     g_strcmp0 (icaltimezone_get_tzid (zone), icaltimezone_get_tzid (cfg_zone)) != 0)) {
 			/* Show timezone part */
 			GtkAction *action;
 
@@ -512,11 +517,17 @@ ece_event_fill_component (ECompEditor *comp_editor,
 		}
 
 		if (set_dtstart) {
+			/* Remove the VALUE parameter, to correspond to the actual value being set */
+			icalproperty_remove_parameter_by_kind (dtstart_prop, ICAL_VALUE_PARAMETER);
+
 			icalproperty_set_dtstart (dtstart_prop, dtstart);
 			cal_comp_util_update_tzid_parameter (dtstart_prop, dtstart);
 		}
 
 		if (set_dtend) {
+			/* Remove the VALUE parameter, to correspond to the actual value being set */
+			icalproperty_remove_parameter_by_kind (dtend_prop, ICAL_VALUE_PARAMETER);
+
 			icalproperty_set_dtend (dtend_prop, dtend);
 			cal_comp_util_update_tzid_parameter (dtend_prop, dtend);
 		}
